/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_Yts9sLRc);
  numBytes += sLine_init(&sLine_UK3METDY);
  numBytes += sLine_init(&sLine_PAbm5gEF);
  numBytes += sLine_init(&sLine_fu5JrUYP);
  numBytes += sLine_init(&sLine_efOlMhxY);
  numBytes += sBiquad_init(&sBiquad_s_vE17FzQs);
  numBytes += sLine_init(&sLine_q9B6mgFu);
  numBytes += sLine_init(&sLine_DY0E1zlG);
  numBytes += sLine_init(&sLine_As661H8n);
  numBytes += sLine_init(&sLine_piehk8eO);
  numBytes += sBiquad_init(&sBiquad_s_EmEpAdIl);
  numBytes += sLine_init(&sLine_spP3CPEF);
  numBytes += sLine_init(&sLine_99vFEFgp);
  numBytes += sLine_init(&sLine_R1BWG6Pt);
  numBytes += sLine_init(&sLine_ss0lkXVD);
  numBytes += sLine_init(&sLine_MManfmm5);
  numBytes += sBiquad_init(&sBiquad_s_GTkzrrOb);
  numBytes += sLine_init(&sLine_NYZPxgVl);
  numBytes += sLine_init(&sLine_i3KpzzzT);
  numBytes += sLine_init(&sLine_e9VjjJlT);
  numBytes += sLine_init(&sLine_roUA4zIx);
  numBytes += sLine_init(&sLine_GvjndoCe);
  numBytes += sBiquad_init(&sBiquad_s_T6Nfm6m8);
  numBytes += sLine_init(&sLine_rDS9Bo1F);
  numBytes += sLine_init(&sLine_ikZ0xpg0);
  numBytes += sLine_init(&sLine_pHEvOFrb);
  numBytes += sLine_init(&sLine_jJRJyVCy);
  numBytes += sBiquad_init(&sBiquad_s_5Nbj91WB);
  numBytes += sLine_init(&sLine_acctVbjZ);
  numBytes += sLine_init(&sLine_mrQv5wUh);
  numBytes += sLine_init(&sLine_dCVuU4pg);
  numBytes += sLine_init(&sLine_TXuHgU9H);
  numBytes += sLine_init(&sLine_yFI4FULV);
  numBytes += sBiquad_init(&sBiquad_s_3CwcCdB3);
  numBytes += sLine_init(&sLine_UQJvqx8y);
  numBytes += sPhasor_k_init(&sPhasor_lXcFKYBf, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_G3plSuL4);
  numBytes += sRPole_init(&sRPole_l9iryK7c);
  numBytes += sRPole_init(&sRPole_32wHJ1dz);
  numBytes += sTabhead_init(&sTabhead_VvZYvazG, &hTable_NELrlLWL);
  numBytes += sTabread_init(&sTabread_JlXlUeyD, &hTable_NELrlLWL, false);
  numBytes += sTabread_init(&sTabread_880xZFb2, &hTable_NELrlLWL, false);
  numBytes += sLine_init(&sLine_KyJADjIw);
  numBytes += sTabhead_init(&sTabhead_cootdAQ8, &hTable_YEX68X0O);
  numBytes += sTabread_init(&sTabread_0HfuxyrF, &hTable_YEX68X0O, false);
  numBytes += sTabread_init(&sTabread_HL7hjG99, &hTable_YEX68X0O, false);
  numBytes += sLine_init(&sLine_xGIFBky0);
  numBytes += sTabwrite_init(&sTabwrite_WUbZ1xYw, &hTable_YEX68X0O);
  numBytes += sTabwrite_init(&sTabwrite_gzEULu5U, &hTable_NELrlLWL);
  numBytes += sLine_init(&sLine_FbWgKnbR);
  numBytes += sPhasor_k_init(&sPhasor_Raj7ZeNN, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_CQ6gJjcR);
  numBytes += sRPole_init(&sRPole_0tTcezA5);
  numBytes += sRPole_init(&sRPole_oyWeuS7P);
  numBytes += sTabhead_init(&sTabhead_LRN8UJjL, &hTable_591hj3AU);
  numBytes += sTabread_init(&sTabread_kPC0lO9A, &hTable_591hj3AU, false);
  numBytes += sTabread_init(&sTabread_2eYOOOD5, &hTable_591hj3AU, false);
  numBytes += sLine_init(&sLine_B4zEHYRA);
  numBytes += sTabhead_init(&sTabhead_0J1SEk3q, &hTable_Pb13gwnA);
  numBytes += sTabread_init(&sTabread_dWYOeE6x, &hTable_Pb13gwnA, false);
  numBytes += sTabread_init(&sTabread_SSMA6h4A, &hTable_Pb13gwnA, false);
  numBytes += sLine_init(&sLine_zj4qC4ub);
  numBytes += sTabwrite_init(&sTabwrite_RXxH6vd1, &hTable_Pb13gwnA);
  numBytes += sTabwrite_init(&sTabwrite_mskV5GBr, &hTable_591hj3AU);
  numBytes += sLine_init(&sLine_Hxyd87Bh);
  numBytes += sPhasor_k_init(&sPhasor_Lh6tQE6Z, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_XDF2IpD5);
  numBytes += sRPole_init(&sRPole_XfnWXOb9);
  numBytes += sRPole_init(&sRPole_Yvox35W4);
  numBytes += sTabhead_init(&sTabhead_jAkFHcxf, &hTable_nTVoy4wi);
  numBytes += sTabread_init(&sTabread_kv7MimPw, &hTable_nTVoy4wi, false);
  numBytes += sTabread_init(&sTabread_u5Sal4vQ, &hTable_nTVoy4wi, false);
  numBytes += sLine_init(&sLine_weiJAgS1);
  numBytes += sTabhead_init(&sTabhead_bIeUymo5, &hTable_GcX4eLjS);
  numBytes += sTabread_init(&sTabread_ENtJTifd, &hTable_GcX4eLjS, false);
  numBytes += sTabread_init(&sTabread_4LzA5ZiX, &hTable_GcX4eLjS, false);
  numBytes += sLine_init(&sLine_XA0p8U5G);
  numBytes += sTabwrite_init(&sTabwrite_I85rRx8m, &hTable_GcX4eLjS);
  numBytes += sTabwrite_init(&sTabwrite_dYXTzyMc, &hTable_nTVoy4wi);
  numBytes += cVar_init_f(&cVar_0XNZRoO8, 0.0f);
  numBytes += cVar_init_f(&cVar_uq7psq9M, 0.0f);
  numBytes += cVar_init_f(&cVar_58wvUsGz, 0.0f);
  numBytes += cVar_init_f(&cVar_4fnJEGkY, 0.0f);
  numBytes += cSlice_init(&cSlice_bmKpMT1h, 1, -1);
  numBytes += cVar_init_f(&cVar_BnQt7NE6, 1337.0f);
  numBytes += cVar_init_f(&cVar_WAcihRK0, 0.0f);
  numBytes += cIf_init(&cIf_ZmUdgcx0, false);
  numBytes += cIf_init(&cIf_XzJMKTnK, false);
  numBytes += cBinop_init(&cBinop_cU9hsPdL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_cIHtZHl5, false);
  numBytes += cBinop_init(&cBinop_hcWhDr1d, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_dzjCKDHG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VZYFCV7h, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_9LXEN1h6, 0.0f);
  numBytes += cIf_init(&cIf_PrtEdyql, false);
  numBytes += cIf_init(&cIf_ZX5Z4ZwY, false);
  numBytes += cBinop_init(&cBinop_pcMPzX7J, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WXiTyiJd, false);
  numBytes += cBinop_init(&cBinop_TXVdMNJg, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1GqJafS9, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_JibBSs75, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Y9BDc9v5, 0.0f);
  numBytes += cIf_init(&cIf_U2od57cJ, false);
  numBytes += cIf_init(&cIf_qJ3uDNqd, false);
  numBytes += cBinop_init(&cBinop_Czvj8sXC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_x8PL0wCL, false);
  numBytes += cBinop_init(&cBinop_I7rYxdzg, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_idvvuNdg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1IfHiK8F, -15.0f); // __eq
  numBytes += cIf_init(&cIf_WzhvsNqN, false);
  numBytes += cSlice_init(&cSlice_B3ry4leQ, 1, -1);
  numBytes += cVar_init_f(&cVar_6rZSpp4N, 0.0f);
  numBytes += cSlice_init(&cSlice_CgbEGhDD, 1, -1);
  numBytes += cVar_init_f(&cVar_770CxnRt, 0.0f);
  numBytes += cSlice_init(&cSlice_yVVTthCt, 1, -1);
  numBytes += cVar_init_f(&cVar_QOQAFDEc, 0.0f);
  numBytes += cSlice_init(&cSlice_GsoYCe61, 1, -1);
  numBytes += cVar_init_f(&cVar_Bzxq42QR, 0.313f);
  numBytes += cBinop_init(&cBinop_uqLUEDv9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JOaZlCzD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PtOM86Qa, 0.0f);
  numBytes += cVar_init_f(&cVar_YCQvZK64, 1337.0f);
  numBytes += cVar_init_f(&cVar_2NTlQ6FY, 0.3f);
  numBytes += cBinop_init(&cBinop_AVdXoHyV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UrsGLizq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_23jrL2Eo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5MMck92Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gt1YpvGS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fA7odpq8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ckwywN3P, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Ww8NRfU4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_pAw7R8El, 0.0f);
  numBytes += cVar_init_f(&cVar_hWPv1W4m, 1337.0f);
  numBytes += cVar_init_f(&cVar_uNgFspGI, 0.313f);
  numBytes += cBinop_init(&cBinop_dytzCxah, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yh8xHSVq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_p27dTWKK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1INAHGSg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Om6dXdkU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FUU7drsS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4fp9Mv9m, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5U9WCZJK, 0.0f);
  numBytes += cVar_init_f(&cVar_2UUI0sGs, 1037.0f);
  numBytes += cVar_init_f(&cVar_Ua4zTvPg, 0.4f);
  numBytes += cBinop_init(&cBinop_PdHysRXi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hsK2PxrH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6X1w9hHK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Vipv1YCh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HTCldFmg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IjZ5YJ4V, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SODHpIm7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O0CokIOS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3BUoc9Un, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_JWeWZPao, 1, -1);
  numBytes += cVar_init_f(&cVar_5sZw0qmS, 1337.0f);
  numBytes += cVar_init_f(&cVar_tx32fSdT, 0.0f);
  numBytes += cIf_init(&cIf_aHVbZwLf, false);
  numBytes += cIf_init(&cIf_Qw8uXouu, false);
  numBytes += cBinop_init(&cBinop_SbCKXMBa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aaeylCw3, false);
  numBytes += cBinop_init(&cBinop_6PdVEpNT, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_MV2s6loJ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bVa0zHdu, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_axa9CS5t, 0.0f);
  numBytes += cIf_init(&cIf_SEzSi9Wa, false);
  numBytes += cIf_init(&cIf_1WoE0CN6, false);
  numBytes += cBinop_init(&cBinop_g2z0O9us, 0.0f); // __pow
  numBytes += cIf_init(&cIf_MM21Yxix, false);
  numBytes += cBinop_init(&cBinop_CMrOiHap, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YGv4GvXB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ewcmO7gP, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_b2v8ifpP, 0.0f);
  numBytes += cIf_init(&cIf_SV3yO5IY, false);
  numBytes += cIf_init(&cIf_TEB3l0M2, false);
  numBytes += cBinop_init(&cBinop_lTyOieXm, 0.0f); // __pow
  numBytes += cIf_init(&cIf_UmEk3W61, false);
  numBytes += cBinop_init(&cBinop_wqWvclGo, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7C2ZBq4Q, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_IvcWzgHj, -15.0f); // __eq
  numBytes += cIf_init(&cIf_gjvnLLey, false);
  numBytes += cSlice_init(&cSlice_IOZxmomA, 1, -1);
  numBytes += cVar_init_f(&cVar_29Pp5Vjl, 0.0f);
  numBytes += cSlice_init(&cSlice_hGxfG0n6, 1, -1);
  numBytes += cVar_init_f(&cVar_BDGlafDG, 0.0f);
  numBytes += cSlice_init(&cSlice_MXBV7pO4, 1, -1);
  numBytes += cVar_init_f(&cVar_hFRSmr2P, 0.0f);
  numBytes += cSlice_init(&cSlice_e5FppGGs, 1, -1);
  numBytes += cVar_init_f(&cVar_wVPRrwdQ, 0.313f);
  numBytes += cBinop_init(&cBinop_j4Mdq1aG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KsKkORz7, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_uJnB95ja, 0.0f);
  numBytes += cVar_init_f(&cVar_Gyu3ed7N, 1337.0f);
  numBytes += cVar_init_f(&cVar_IR1LsEeQ, 0.3f);
  numBytes += cBinop_init(&cBinop_yW68Yzkm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DfrTXeQ9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4pLO4qL2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_48ti68RV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nU6pyaFl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZJcGSpl2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gOLgTRBf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_1o5juWz0, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_HqFtgHEX, 0.0f);
  numBytes += cVar_init_f(&cVar_HdTFQ98W, 1337.0f);
  numBytes += cVar_init_f(&cVar_VxoMEVYc, 0.313f);
  numBytes += cBinop_init(&cBinop_EsKJhWfz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ijgpign6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_I4EeEwBX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hv1WkjrR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KEmo62t0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Rb9wcFp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pPNZcKBT, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5f2mZvrA, 0.0f);
  numBytes += cVar_init_f(&cVar_Hir1HgGj, 1037.0f);
  numBytes += cVar_init_f(&cVar_YTMVV1EU, 0.4f);
  numBytes += cBinop_init(&cBinop_T5hyW49H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zRk5yJE8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Nqi1KzBa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n4XYx1A0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0iI1Dz6W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aizKiMHC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_uHAkCt42, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oKNxUuc2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MqlUk40j, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Iu9AgWy0, 5705.6f);
  numBytes += cVar_init_f(&cVar_rlEiWYOE, 313.3f);
  numBytes += cBinop_init(&cBinop_Gx4FRYrZ, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_AHitZZVC, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_GMYCiVww, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_NTspab9x, 0.0f);
  numBytes += cVar_init_f(&cVar_IpCVdNQI, 0.0f);
  numBytes += cVar_init_f(&cVar_LVdlUR0y, 0.0f);
  numBytes += cVar_init_f(&cVar_kOWJGR72, 0.0f);
  numBytes += cVar_init_f(&cVar_x0bGZiPl, 0.0f);
  numBytes += cVar_init_f(&cVar_0ZRA9uMC, 0.0f);
  numBytes += cVar_init_f(&cVar_9AIOH88U, 0.0f);
  numBytes += cVar_init_f(&cVar_qWcZ6Pbj, 0.0f);
  numBytes += cVar_init_f(&cVar_VyAfERtk, 0.0f);
  numBytes += cVar_init_f(&cVar_UwWAu8kU, 0.0f);
  numBytes += cVar_init_f(&cVar_mQyeqBdi, 0.0f);
  numBytes += cVar_init_f(&cVar_Id55EDy2, 0.0f);
  numBytes += cVar_init_s(&cVar_KTAmkUaB, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_v2tA4D1T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VdJTyCeg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZvRcfCFh, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_39szFUPV, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_vsAeVip9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EKYTXHPE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CTOwbg1i, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_0Y5JvreQ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_L7D68aJ3, 0.0f);
  numBytes += hTable_init(&hTable_YEX68X0O, 256);
  numBytes += cDelay_init(this, &cDelay_Xgzyjqaz, 0.0f);
  numBytes += cDelay_init(this, &cDelay_N8LUAEbi, 0.0f);
  numBytes += hTable_init(&hTable_NELrlLWL, 256);
  numBytes += cVar_init_f(&cVar_ohQIrNam, 14.0f);
  numBytes += cBinop_init(&cBinop_VpFH38Zx, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Cy0tcwIZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ACQIkKjG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ReNS35jq, 14.0f);
  numBytes += cBinop_init(&cBinop_XD0LBsXw, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_4nSKrMYS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a4UpEMO1, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Y0QZO59Q, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_buiqE0Ht, 1, -1);
  numBytes += cVar_init_f(&cVar_YG0gF8Jq, 0.2f);
  numBytes += cSlice_init(&cSlice_r8C0ShuO, 1, -1);
  numBytes += cVar_init_f(&cVar_0S2r3TPR, 0.0f);
  numBytes += cSlice_init(&cSlice_FSr44Etu, 1, -1);
  numBytes += cVar_init_f(&cVar_ZiuUIdhn, 2.0f);
  numBytes += cSlice_init(&cSlice_XYMyh79I, 1, -1);
  numBytes += cVar_init_f(&cVar_3LkfoZRa, 0.5f);
  numBytes += cVar_init_s(&cVar_mBiG9hvp, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_6qaoWCeX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oNWYSEWR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rbda3ll1, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_55ZE1n27, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_Wfj17syK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I6w7OXmC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SbSna2LP, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_BEdsWSHR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WUeQDQLO, 0.0f);
  numBytes += hTable_init(&hTable_Pb13gwnA, 256);
  numBytes += cDelay_init(this, &cDelay_N5ZMvK5V, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NDRj8Dfo, 0.0f);
  numBytes += hTable_init(&hTable_591hj3AU, 256);
  numBytes += cVar_init_f(&cVar_uiuet9yv, 14.0f);
  numBytes += cBinop_init(&cBinop_TnZPvGcW, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zNyL3kzj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Fkpb8h1q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1J2aN6ug, 14.0f);
  numBytes += cBinop_init(&cBinop_sc5t5v3H, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6GZ4ThXZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zv5ujA3e, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_j7RoCvy8, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_1ddgrRnW, 1, -1);
  numBytes += cVar_init_f(&cVar_WhcEUR5q, 0.2f);
  numBytes += cSlice_init(&cSlice_ZCaZlIZ2, 1, -1);
  numBytes += cVar_init_f(&cVar_FL3qCSbI, 0.0f);
  numBytes += cSlice_init(&cSlice_vb0lWCzG, 1, -1);
  numBytes += cVar_init_f(&cVar_rn5pIPkS, 2.0f);
  numBytes += cSlice_init(&cSlice_U1N4d5o2, 1, -1);
  numBytes += cVar_init_f(&cVar_prdf5GU1, 0.5f);
  numBytes += cVar_init_s(&cVar_A3xf6yci, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_8g6uI2dG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A4MscM5E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X8B2vEvx, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_TUed2Hhf, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_ddighjGB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UN65DTka, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9u4ry4Xv, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_3XpKjRe8, 0.0f);
  numBytes += cDelay_init(this, &cDelay_DpUV2KP9, 0.0f);
  numBytes += hTable_init(&hTable_GcX4eLjS, 256);
  numBytes += cDelay_init(this, &cDelay_clPhCfEg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zuAj49Kv, 0.0f);
  numBytes += hTable_init(&hTable_nTVoy4wi, 256);
  numBytes += cVar_init_f(&cVar_e2gxpPZD, 14.0f);
  numBytes += cBinop_init(&cBinop_Ohjh7BCT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_z0VlazzF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AgamUPlM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_tKp3Gf3x, 14.0f);
  numBytes += cBinop_init(&cBinop_ZSVqgQqO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_30yIHaW8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GLNZcCTg, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_F6cucBA7, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_1rKROwRG, 1, -1);
  numBytes += cVar_init_f(&cVar_2jH3Ge2t, 0.2f);
  numBytes += cSlice_init(&cSlice_lbpyAnUM, 1, -1);
  numBytes += cVar_init_f(&cVar_4ctkH2zp, 0.0f);
  numBytes += cSlice_init(&cSlice_mrGnehtx, 1, -1);
  numBytes += cVar_init_f(&cVar_m37Gwzyw, 2.0f);
  numBytes += cSlice_init(&cSlice_PCuoGzHX, 1, -1);
  numBytes += cVar_init_f(&cVar_L7BFXkWu, 0.5f);
  numBytes += sVarf_init(&sVarf_0x4lrt8Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NekcUCOR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8xrWvZyF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fldbemG9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C4eAI0b3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6U4LRD4I, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_YEX68X0O);
  hTable_free(&hTable_NELrlLWL);
  hTable_free(&hTable_Pb13gwnA);
  hTable_free(&hTable_591hj3AU);
  hTable_free(&hTable_GcX4eLjS);
  hTable_free(&hTable_nTVoy4wi);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_YEX68X0O; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_NELrlLWL; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_Pb13gwnA; // del-1397-flanger-r
    case 0x578173CB: return &hTable_591hj3AU; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_GcX4eLjS; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_nTVoy4wi; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7YyieX0R_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9EKyjO8y_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fIi35fh3_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1KKN8OBb_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xLXs2whU_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pgnjfCxP_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XnDR7MTb_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I84xVzkX_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7uTtxM34_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eSdfSGWN_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3RFqTazV_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1ZFud0lv_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ddcy27wO_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jRMNUNW9_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XDWeuqwH_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fYxnWyro_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9KlsZH2o_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nV7rlx1D_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oBqp5vPg_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SLlnmlqO_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RM8cinzQ_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BQz4UCO5_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4G3kkZBm_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C42k7DUp_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LeeMGnkT_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0CvRPipF_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jGHfDumw_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sNe4EOtM_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rK7eOatK_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t4jGTr7u_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VT7eUu5R_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Du9Tklha_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QdF9Rokw_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VhJrXioN_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QKQjqV2t_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CG2CqRY4_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AtX8rZ0M_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MGYvkbTd_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m5v7J3kl_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WNA0hP8P_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CwqP83Hc_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_51bxUicd_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jLxnxVly_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PV5DvH7u_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tBUwCYiZ_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6eE83OJB_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xrqz6fxo_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iJjoeJ4m_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ecvStRd5_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JlG3nc7E_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rvD3vCXc_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GSVONXXY_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HxRAA8Dl_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ho1fumo0_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VZENmdvU_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Frj0S6ty_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PEbgA7Y6_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_0XNZRoO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LFj09Tsg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_uq7psq9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3I6VLaru_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_58wvUsGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pZqbtaaL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_4fnJEGkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u9iDglzA_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q7K1cmWn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rD33oI0m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oTPVyarj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_4qIgbCto_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bmKpMT1h, 0, m, &cSlice_bmKpMT1h_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Z0raa5rB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_bmKpMT1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4l46m4cr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4l46m4cr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_BnQt7NE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4l46m4cr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4l46m4cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oBqp5vPg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_WAcihRK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BP6QhKn1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ZmUdgcx0, 0, m, &cIf_ZmUdgcx0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ZmUdgcx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Yyjyr5lD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_XzJMKTnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_OOrKgzkS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_witWWFFT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_SVFbglkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cU9hsPdL, HV_BINOP_POW, 0, m, &cBinop_cU9hsPdL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cU9hsPdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cIHtZHl5, 0, m, &cIf_cIHtZHl5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ARFHYVnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_VZOUmP4B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8IL9QGGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XzJMKTnK, 0, m, &cIf_XzJMKTnK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_neCWfS1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QNkOWzDM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QNkOWzDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XzJMKTnK, 1, m, &cIf_XzJMKTnK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_witWWFFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ARFHYVnX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OOrKgzkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_cIHtZHl5, 0, m, &cIf_cIHtZHl5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VZOUmP4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cU9hsPdL, HV_BINOP_POW, 1, m, &cBinop_cU9hsPdL_sendMessage);
  cMsg_SVFbglkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_cIHtZHl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_SODHpIm7, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_BP6QhKn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZmUdgcx0, 1, m, &cIf_ZmUdgcx0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Yyjyr5lD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dzjCKDHG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dzjCKDHG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VZYFCV7h, HV_BINOP_EQ, 1, m, &cBinop_VZYFCV7h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fNmvB8wS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hcWhDr1d, HV_BINOP_ADD, 0, m, &cBinop_hcWhDr1d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hcWhDr1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_neCWfS1s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8IL9QGGA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dzjCKDHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cIHtZHl5, 1, m, &cIf_cIHtZHl5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VZYFCV7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8q61HDF5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8q61HDF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SODHpIm7, m);
}

void Heavy_WSTD_FL3NGR::cCast_CD4wcyP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hcWhDr1d, HV_BINOP_ADD, 1, m, &cBinop_hcWhDr1d_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dzjCKDHG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dzjCKDHG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VZYFCV7h, HV_BINOP_EQ, 0, m, &cBinop_VZYFCV7h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kp4o5CPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WAcihRK0, 0, m, &cVar_WAcihRK0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mRlkL17a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fNmvB8wS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9LXEN1h6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JGzcoW6L_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PrtEdyql, 0, m, &cIf_PrtEdyql_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_PrtEdyql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_g2WrBFXa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_ZX5Z4ZwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WBWVsDI3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_hll8DUHG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_gkb9QCrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcMPzX7J, HV_BINOP_POW, 0, m, &cBinop_pcMPzX7J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pcMPzX7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WXiTyiJd, 0, m, &cIf_WXiTyiJd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CAQTfnlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_QHioba4o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_FmQZhp8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZX5Z4ZwY, 0, m, &cIf_ZX5Z4ZwY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_S0M0oMP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yRDy5uNZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yRDy5uNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZX5Z4ZwY, 1, m, &cIf_ZX5Z4ZwY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hll8DUHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_CAQTfnlJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WBWVsDI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WXiTyiJd, 0, m, &cIf_WXiTyiJd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QHioba4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcMPzX7J, HV_BINOP_POW, 1, m, &cBinop_pcMPzX7J_sendMessage);
  cMsg_gkb9QCrt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_WXiTyiJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R5iwTOyK_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_o6g2WtUK_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Vgojf2bI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_JGzcoW6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PrtEdyql, 1, m, &cIf_PrtEdyql_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g2WrBFXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GqJafS9, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1GqJafS9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JibBSs75, HV_BINOP_EQ, 1, m, &cBinop_JibBSs75_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0H0pWWV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TXVdMNJg, HV_BINOP_ADD, 0, m, &cBinop_TXVdMNJg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TXVdMNJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S0M0oMP4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FmQZhp8b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1GqJafS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WXiTyiJd, 1, m, &cIf_WXiTyiJd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JibBSs75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i8QdDbcL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_i8QdDbcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R5iwTOyK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_o6g2WtUK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Vgojf2bI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zOIQzX8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TXVdMNJg, HV_BINOP_ADD, 1, m, &cBinop_TXVdMNJg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GqJafS9, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1GqJafS9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JibBSs75, HV_BINOP_EQ, 0, m, &cBinop_JibBSs75_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6KfxnDJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9LXEN1h6, 0, m, &cVar_9LXEN1h6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NlYqPaPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0H0pWWV6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Y9BDc9v5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oM5ndcHc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_U2od57cJ, 0, m, &cIf_U2od57cJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_U2od57cJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qFFcHcbB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_qJ3uDNqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_l3tux50Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_15D3SW3N_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_sm6rQEDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Czvj8sXC, HV_BINOP_POW, 0, m, &cBinop_Czvj8sXC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Czvj8sXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x8PL0wCL, 0, m, &cIf_x8PL0wCL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a7sCf5fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_yI7Ga4gm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bNnj8scK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qJ3uDNqd, 0, m, &cIf_qJ3uDNqd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0j70XBvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BAT8reoV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BAT8reoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qJ3uDNqd, 1, m, &cIf_qJ3uDNqd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_15D3SW3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_a7sCf5fc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_l3tux50Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_x8PL0wCL, 0, m, &cIf_x8PL0wCL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yI7Ga4gm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Czvj8sXC, HV_BINOP_POW, 1, m, &cBinop_Czvj8sXC_sendMessage);
  cMsg_sm6rQEDA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_x8PL0wCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_3BUoc9Un, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_oM5ndcHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U2od57cJ, 1, m, &cIf_U2od57cJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qFFcHcbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_idvvuNdg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_idvvuNdg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1IfHiK8F, HV_BINOP_EQ, 1, m, &cBinop_1IfHiK8F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_QegMum6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I7rYxdzg, HV_BINOP_ADD, 0, m, &cBinop_I7rYxdzg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_I7rYxdzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0j70XBvm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bNnj8scK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_idvvuNdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x8PL0wCL, 1, m, &cIf_x8PL0wCL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1IfHiK8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RzRIsF0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RzRIsF0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3BUoc9Un, m);
}

void Heavy_WSTD_FL3NGR::cCast_zoTcqkoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I7rYxdzg, HV_BINOP_ADD, 1, m, &cBinop_I7rYxdzg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_idvvuNdg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_idvvuNdg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1IfHiK8F, HV_BINOP_EQ, 0, m, &cBinop_1IfHiK8F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZXWIEURj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y9BDc9v5, 0, m, &cVar_Y9BDc9v5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tUbw4yIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QegMum6w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_WzhvsNqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_O0CokIOS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xxMEvDoX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B3ry4leQ, 0, m, &cSlice_B3ry4leQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_apEHj2nQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_B3ry4leQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XmtxEK0v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XmtxEK0v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6rZSpp4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XmtxEK0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XmtxEK0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9KlsZH2o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_apEHj2nQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CgbEGhDD, 0, m, &cSlice_CgbEGhDD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4qIgbCto_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_CgbEGhDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7AEKpGMS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7AEKpGMS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_770CxnRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7AEKpGMS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7AEKpGMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RM8cinzQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Z0raa5rB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yVVTthCt, 0, m, &cSlice_yVVTthCt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9OoUnkuq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_yVVTthCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EB0S8NC7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EB0S8NC7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_QOQAFDEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EB0S8NC7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_EB0S8NC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nV7rlx1D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_9OoUnkuq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GsoYCe61, 0, m, &cSlice_GsoYCe61_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_GsoYCe61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5k77A2Oj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5k77A2Oj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Bzxq42QR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5k77A2Oj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5k77A2Oj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SLlnmlqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_m4nnyOA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yts9sLRc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_obo5EkC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UK3METDY, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VLWpGfI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PAbm5gEF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JST9I9sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fu5JrUYP, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AgG3SsM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_efOlMhxY, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JMieYlC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dhRhkNJp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_dhRhkNJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uqLUEDv9, HV_BINOP_DIVIDE, 1, m, &cBinop_uqLUEDv9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vtoijAom_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_XL3ViWtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ZDEx60HE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_llVBYii2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_XL3ViWtY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZDEx60HE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uqLUEDv9, HV_BINOP_DIVIDE, 0, m, &cBinop_uqLUEDv9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vtoijAom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_llVBYii2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uqLUEDv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JOaZlCzD, HV_BINOP_MULTIPLY, 1, m, &cBinop_JOaZlCzD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JOaZlCzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XnNybKsF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_feuAIHJn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_HLHXOdly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xAgwB8EY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_UkHUdKj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sBGHf4zS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UtHogBZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_XY5G7c93_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XY5G7c93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JOaZlCzD, HV_BINOP_MULTIPLY, 0, m, &cBinop_JOaZlCzD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C3RY69LA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LeIh8jpC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LeIh8jpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4vlOTdyi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rqMQeMfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PtOM86Qa, 1, m, &cVar_PtOM86Qa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_PtOM86Qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gl5K39Qy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ylSXksqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UrsGLizq, HV_BINOP_MULTIPLY, 1, m, &cBinop_UrsGLizq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wpGyV15J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ylSXksqO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RfgTgQxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OLsL1Ae7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OLsL1Ae7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_23jrL2Eo, HV_BINOP_MULTIPLY, 1, m, &cBinop_23jrL2Eo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VaKhkKGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5MMck92Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_5MMck92Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_co1k4lwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VaKhkKGQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N0Y5LcG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gt1YpvGS, HV_BINOP_MULTIPLY, 1, m, &cBinop_gt1YpvGS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_p4j9wUtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QFCKsDcM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QFCKsDcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fA7odpq8, HV_BINOP_MULTIPLY, 1, m, &cBinop_fA7odpq8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_YCQvZK64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tPJWUZQ7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UtHogBZ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IIgOSlyf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_2NTlQ6FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_C3RY69LA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_feuAIHJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_UkHUdKj7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XnNybKsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_HLHXOdly_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_xAgwB8EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C42k7DUp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_sBGHf4zS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4G3kkZBm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MdhpzGoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BQz4UCO5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4vlOTdyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_C23OTrG2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_C23OTrG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AVdXoHyV, HV_BINOP_MULTIPLY, 1, m, &cBinop_AVdXoHyV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AVdXoHyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ycZMK3ee_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ycZMK3ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MdhpzGoO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_gl5K39Qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Ije3ckaZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ije3ckaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g8KFplhK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JLgFNzFc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_emakwMsc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IhxN5oaw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yKGkNaly_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X04nTcmV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UrsGLizq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m4nnyOA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_23jrL2Eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_obo5EkC3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_5MMck92Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VLWpGfI0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gt1YpvGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JST9I9sy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_fA7odpq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AgG3SsM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_oe9XetDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YCQvZK64, 0, m, &cVar_YCQvZK64_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zCAKXogg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2NTlQ6FY, 1, m, &cVar_2NTlQ6FY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_X04nTcmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UrsGLizq, HV_BINOP_MULTIPLY, 0, m, &cBinop_UrsGLizq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_emakwMsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gt1YpvGS, HV_BINOP_MULTIPLY, 0, m, &cBinop_gt1YpvGS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yKGkNaly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_23jrL2Eo, HV_BINOP_MULTIPLY, 0, m, &cBinop_23jrL2Eo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JLgFNzFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fA7odpq8, HV_BINOP_MULTIPLY, 0, m, &cBinop_fA7odpq8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IhxN5oaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5MMck92Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_5MMck92Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_g8KFplhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_tPJWUZQ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2NTlQ6FY, 0, m, &cVar_2NTlQ6FY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IIgOSlyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PtOM86Qa, 0, m, &cVar_PtOM86Qa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XWwdLP2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q9B6mgFu, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_BR4O6rlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DY0E1zlG, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZDZMcSkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_As661H8n, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_on2kOw6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_piehk8eO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_w4y0XgpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qZu6Tnou_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_qZu6Tnou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckwywN3P, HV_BINOP_DIVIDE, 1, m, &cBinop_ckwywN3P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qO5qdt72_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ZYgjKTkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_9IzZBZ1l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_AyJ5SSof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ZYgjKTkB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9IzZBZ1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckwywN3P, HV_BINOP_DIVIDE, 0, m, &cBinop_ckwywN3P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qO5qdt72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AyJ5SSof_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ckwywN3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ww8NRfU4, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ww8NRfU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ww8NRfU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KSKFfH2W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JBHUxVJC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_xlQQARax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0keWLlGX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_nN7lak1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MN4ppcoA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0F47BC0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_cC8HQoJ5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cC8HQoJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ww8NRfU4, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ww8NRfU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nLGXs7BT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6tXSS6rn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6tXSS6rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aa5RS84K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_iWDRA4uU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p27dTWKK, HV_BINOP_MULTIPLY, 1, m, &cBinop_p27dTWKK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ebDwyeRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pAw7R8El, 1, m, &cVar_pAw7R8El_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jqJvqi14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1INAHGSg, HV_BINOP_MULTIPLY, 1, m, &cBinop_1INAHGSg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4ItMSslU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JTy5ebCK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JTy5ebCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Om6dXdkU, HV_BINOP_MULTIPLY, 1, m, &cBinop_Om6dXdkU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_pAw7R8El_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RzGj1TQr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_hWPv1W4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_19efxhdV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_0F47BC0M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TjaaWdzg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_uNgFspGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_nLGXs7BT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KSKFfH2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xlQQARax_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JBHUxVJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nN7lak1z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_0keWLlGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jGHfDumw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MN4ppcoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0CvRPipF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_F5ZUH8rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LeeMGnkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aa5RS84K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BLiVQWr0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BLiVQWr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dytzCxah, HV_BINOP_MULTIPLY, 1, m, &cBinop_dytzCxah_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dytzCxah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uxSY6n5M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uxSY6n5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_F5ZUH8rX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_RzGj1TQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ANEC21K6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ANEC21K6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_URePUCrV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GonnErQ1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UUHYBRXf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y1o7RXRQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yh8xHSVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XWwdLP2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_p27dTWKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BR4O6rlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1INAHGSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZDZMcSkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Om6dXdkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_on2kOw6O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_XbUO6IUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uNgFspGI, 1, m, &cVar_uNgFspGI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_spLvjely_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hWPv1W4m, 0, m, &cVar_hWPv1W4m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TjaaWdzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pAw7R8El, 0, m, &cVar_pAw7R8El_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_19efxhdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uNgFspGI, 0, m, &cVar_uNgFspGI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Y1o7RXRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yh8xHSVq, HV_BINOP_MULTIPLY, 0, m, &cBinop_yh8xHSVq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_URePUCrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Om6dXdkU, HV_BINOP_MULTIPLY, 0, m, &cBinop_Om6dXdkU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UUHYBRXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p27dTWKK, HV_BINOP_MULTIPLY, 0, m, &cBinop_p27dTWKK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GonnErQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1INAHGSg, HV_BINOP_MULTIPLY, 0, m, &cBinop_1INAHGSg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_DyWq01k3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_spP3CPEF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GFr8Yeik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_99vFEFgp, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QV4fa9QT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R1BWG6Pt, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hfQrYfy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ss0lkXVD, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xzxIu6De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MManfmm5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IdHBvESd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hatgAUpG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_hatgAUpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FUU7drsS, HV_BINOP_DIVIDE, 1, m, &cBinop_FUU7drsS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ui1iObXP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_TMIKcTER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fCuWQPNE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3RGppAfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_TMIKcTER_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fCuWQPNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FUU7drsS, HV_BINOP_DIVIDE, 0, m, &cBinop_FUU7drsS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ui1iObXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3RGppAfO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FUU7drsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4fp9Mv9m, HV_BINOP_MULTIPLY, 1, m, &cBinop_4fp9Mv9m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4fp9Mv9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ENO63Gg3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ogGY7Uft_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_iipBbFwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JvzCVYUK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_V3X9Tz0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v4yCISkm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FRn7HbJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_KXKeIf0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KXKeIf0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4fp9Mv9m, HV_BINOP_MULTIPLY, 0, m, &cBinop_4fp9Mv9m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iLhMYM1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ATiqqpLb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ATiqqpLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1O7sxEZU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KDStMB8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hsK2PxrH, HV_BINOP_MULTIPLY, 1, m, &cBinop_hsK2PxrH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ro0c41o4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MZv4jZUU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MZv4jZUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KDStMB8c_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ACTIxLgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lMZJT9oC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lMZJT9oC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6X1w9hHK, HV_BINOP_MULTIPLY, 1, m, &cBinop_6X1w9hHK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uXqopS9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vipv1YCh, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vipv1YCh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_lYw65POk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5KYW6Okn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5KYW6Okn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uXqopS9U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mWIycuIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5U9WCZJK, 1, m, &cVar_5U9WCZJK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MD5XiroQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HTCldFmg, HV_BINOP_MULTIPLY, 1, m, &cBinop_HTCldFmg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OQlN4eVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mOi2q0YS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mOi2q0YS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IjZ5YJ4V, HV_BINOP_MULTIPLY, 1, m, &cBinop_IjZ5YJ4V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5U9WCZJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ugOx8ob_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_2UUI0sGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7gGK8vS2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FRn7HbJ7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2W74MtoY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Ua4zTvPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iLhMYM1u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ogGY7Uft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_V3X9Tz0W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ENO63Gg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_iipBbFwd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_JvzCVYUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t4jGTr7u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_v4yCISkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rK7eOatK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Ak8AfylP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sNe4EOtM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1O7sxEZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7PLX8rnm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7PLX8rnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PdHysRXi, HV_BINOP_MULTIPLY, 1, m, &cBinop_PdHysRXi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PdHysRXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0PVtGcGP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0PVtGcGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ak8AfylP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_6ugOx8ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_e04aA06N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_e04aA06N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TbUwiBBr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RTmqw6UB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8VP9O8f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RBXKy5VF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Dp9U7NN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E6fUOp0z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hsK2PxrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DyWq01k3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6X1w9hHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GFr8Yeik_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Vipv1YCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QV4fa9QT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HTCldFmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hfQrYfy9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IjZ5YJ4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xzxIu6De_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_qdNTI9i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ua4zTvPg, 1, m, &cVar_Ua4zTvPg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_U7mfkONp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2UUI0sGs, 0, m, &cVar_2UUI0sGs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E6fUOp0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hsK2PxrH, HV_BINOP_MULTIPLY, 0, m, &cBinop_hsK2PxrH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Q8VP9O8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HTCldFmg, HV_BINOP_MULTIPLY, 0, m, &cBinop_HTCldFmg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9Dp9U7NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6X1w9hHK, HV_BINOP_MULTIPLY, 0, m, &cBinop_6X1w9hHK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RTmqw6UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IjZ5YJ4V, HV_BINOP_MULTIPLY, 0, m, &cBinop_IjZ5YJ4V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RBXKy5VF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vipv1YCh, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vipv1YCh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TbUwiBBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_2W74MtoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5U9WCZJK, 0, m, &cVar_5U9WCZJK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7gGK8vS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ua4zTvPg, 0, m, &cVar_Ua4zTvPg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R5iwTOyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WzhvsNqN, 1, m, &cIf_WzhvsNqN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_W0crHwn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_O0CokIOS, m);
}

void Heavy_WSTD_FL3NGR::cBinop_o6g2WtUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W0crHwn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Vgojf2bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WzhvsNqN, 0, m, &cIf_WzhvsNqN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_4JbXVokU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JWeWZPao, 0, m, &cSlice_JWeWZPao_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JSqn9on7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_JWeWZPao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_u0B5atHJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_u0B5atHJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_5sZw0qmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_u0B5atHJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_u0B5atHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QdF9Rokw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_tx32fSdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CSEsX8aY_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_aHVbZwLf, 0, m, &cIf_aHVbZwLf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_aHVbZwLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CUp7TmCH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_Qw8uXouu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_4jCLuu7y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_h4pzZbaF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_pqzX6a9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SbCKXMBa, HV_BINOP_POW, 0, m, &cBinop_SbCKXMBa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SbCKXMBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aaeylCw3, 0, m, &cIf_aaeylCw3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Sczr6JgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_WALC2lFH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vOz0v3A7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qw8uXouu, 0, m, &cIf_Qw8uXouu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Uz6l9Kot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W2m26wFr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W2m26wFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qw8uXouu, 1, m, &cIf_Qw8uXouu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h4pzZbaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Sczr6JgE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4jCLuu7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aaeylCw3, 0, m, &cIf_aaeylCw3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WALC2lFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SbCKXMBa, HV_BINOP_POW, 1, m, &cBinop_SbCKXMBa_sendMessage);
  cMsg_pqzX6a9V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_aaeylCw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_uHAkCt42, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_CSEsX8aY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aHVbZwLf, 1, m, &cIf_aHVbZwLf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CUp7TmCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MV2s6loJ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_MV2s6loJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVa0zHdu, HV_BINOP_EQ, 1, m, &cBinop_bVa0zHdu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_W0DnYqKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6PdVEpNT, HV_BINOP_ADD, 0, m, &cBinop_6PdVEpNT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6PdVEpNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uz6l9Kot_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vOz0v3A7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MV2s6loJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aaeylCw3, 1, m, &cIf_aaeylCw3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bVa0zHdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OvT7jK6R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OvT7jK6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uHAkCt42, m);
}

void Heavy_WSTD_FL3NGR::cCast_TeIEgK5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W0DnYqKZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_0lh1lGLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6PdVEpNT, HV_BINOP_ADD, 1, m, &cBinop_6PdVEpNT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MV2s6loJ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_MV2s6loJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVa0zHdu, HV_BINOP_EQ, 0, m, &cBinop_bVa0zHdu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_u2cgrONQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tx32fSdT, 0, m, &cVar_tx32fSdT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_axa9CS5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gLxwkUUU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SEzSi9Wa, 0, m, &cIf_SEzSi9Wa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_SEzSi9Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_N5UD2x87_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_1WoE0CN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_0jgqqV5l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_PtRl9VH3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_fnSlyZqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g2z0O9us, HV_BINOP_POW, 0, m, &cBinop_g2z0O9us_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g2z0O9us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MM21Yxix, 0, m, &cIf_MM21Yxix_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZfuoP8u5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3m5dRn6T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jrKvURQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QNmjC9ZR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gbAOd9Oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1WoE0CN6, 0, m, &cIf_1WoE0CN6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QNmjC9ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1WoE0CN6, 1, m, &cIf_1WoE0CN6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PtRl9VH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZfuoP8u5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0jgqqV5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MM21Yxix, 0, m, &cIf_MM21Yxix_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3m5dRn6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g2z0O9us, HV_BINOP_POW, 1, m, &cBinop_g2z0O9us_sendMessage);
  cMsg_fnSlyZqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_MM21Yxix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mnzmgw6p_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LS54xZO4_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Mt7E5vaI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_gLxwkUUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SEzSi9Wa, 1, m, &cIf_SEzSi9Wa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N5UD2x87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YGv4GvXB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YGv4GvXB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ewcmO7gP, HV_BINOP_EQ, 1, m, &cBinop_ewcmO7gP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ix5WQOWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CMrOiHap, HV_BINOP_ADD, 0, m, &cBinop_CMrOiHap_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CMrOiHap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jrKvURQ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gbAOd9Oa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YGv4GvXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MM21Yxix, 1, m, &cIf_MM21Yxix_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ewcmO7gP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_50OsbBLR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_50OsbBLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mnzmgw6p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LS54xZO4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Mt7E5vaI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_n3uK5lrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_axa9CS5t, 0, m, &cVar_axa9CS5t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1050jE3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ix5WQOWa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Fp6aoMRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CMrOiHap, HV_BINOP_ADD, 1, m, &cBinop_CMrOiHap_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YGv4GvXB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YGv4GvXB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ewcmO7gP, HV_BINOP_EQ, 0, m, &cBinop_ewcmO7gP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_b2v8ifpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DHywoeDK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_SV3yO5IY, 0, m, &cIf_SV3yO5IY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_SV3yO5IY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7UkzbQjn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_TEB3l0M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_H2pQgyNg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uxUueH4W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_U7lieY2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lTyOieXm, HV_BINOP_POW, 0, m, &cBinop_lTyOieXm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lTyOieXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UmEk3W61, 0, m, &cIf_UmEk3W61_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cFXzXMEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_i7tOs552_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1S7SY6QG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TEB3l0M2, 0, m, &cIf_TEB3l0M2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lc3Cfa2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_56DR8QZ4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_56DR8QZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TEB3l0M2, 1, m, &cIf_TEB3l0M2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uxUueH4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_cFXzXMEu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_H2pQgyNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_UmEk3W61, 0, m, &cIf_UmEk3W61_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_i7tOs552_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lTyOieXm, HV_BINOP_POW, 1, m, &cBinop_lTyOieXm_sendMessage);
  cMsg_U7lieY2F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_UmEk3W61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_MqlUk40j, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_DHywoeDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SV3yO5IY, 1, m, &cIf_SV3yO5IY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7UkzbQjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7C2ZBq4Q, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7C2ZBq4Q_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvcWzgHj, HV_BINOP_EQ, 1, m, &cBinop_IvcWzgHj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oZZy9OSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wqWvclGo, HV_BINOP_ADD, 0, m, &cBinop_wqWvclGo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wqWvclGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lc3Cfa2V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1S7SY6QG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7C2ZBq4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UmEk3W61, 1, m, &cIf_UmEk3W61_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IvcWzgHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PB02f7Nv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PB02f7Nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MqlUk40j, m);
}

void Heavy_WSTD_FL3NGR::cCast_csQVm6hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_b2v8ifpP, 0, m, &cVar_b2v8ifpP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xJIPdOtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oZZy9OSq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_zD7xPdrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wqWvclGo, HV_BINOP_ADD, 1, m, &cBinop_wqWvclGo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7C2ZBq4Q, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7C2ZBq4Q_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvcWzgHj, HV_BINOP_EQ, 0, m, &cBinop_IvcWzgHj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_gjvnLLey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_oKNxUuc2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Xj7MZwzd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IOZxmomA, 0, m, &cSlice_IOZxmomA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2Q1caIFu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_IOZxmomA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_x95fOnUK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_x95fOnUK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_29Pp5Vjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_x95fOnUK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_x95fOnUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VT7eUu5R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2Q1caIFu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hGxfG0n6, 0, m, &cSlice_hGxfG0n6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4JbXVokU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_hGxfG0n6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5fZ2ZlUr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5fZ2ZlUr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_BDGlafDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5fZ2ZlUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5fZ2ZlUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QKQjqV2t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_JSqn9on7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MXBV7pO4, 0, m, &cSlice_MXBV7pO4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6gsiHKPD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_MXBV7pO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NxCij281_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NxCij281_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_hFRSmr2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NxCij281_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_NxCij281_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Du9Tklha_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_6gsiHKPD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_e5FppGGs, 0, m, &cSlice_e5FppGGs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_e5FppGGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zuGY8oBd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zuGY8oBd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_wVPRrwdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zuGY8oBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_zuGY8oBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VhJrXioN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fU3CNjN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NYZPxgVl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8dp9PUIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i3KpzzzT, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_VU2H8fiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e9VjjJlT, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PYmyvrTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_roUA4zIx, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_KErgEiDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GvjndoCe, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_00Mol4mX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_55dXYNSH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_55dXYNSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j4Mdq1aG, HV_BINOP_DIVIDE, 1, m, &cBinop_j4Mdq1aG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7IGznmWv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_pfWnMsMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dbhat8PG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eITSeasO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_pfWnMsMt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dbhat8PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j4Mdq1aG, HV_BINOP_DIVIDE, 0, m, &cBinop_j4Mdq1aG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7IGznmWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eITSeasO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_j4Mdq1aG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsKkORz7, HV_BINOP_MULTIPLY, 1, m, &cBinop_KsKkORz7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KsKkORz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ry8kT2ED_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rVS41Yya_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_tCjeJHIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vlIAVd2s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_QvvT58wU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MVpgbtiH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oqJC0oPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_TufPdwDp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TufPdwDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsKkORz7, HV_BINOP_MULTIPLY, 0, m, &cBinop_KsKkORz7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dAiKL9Y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_DpUnBl3p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DpUnBl3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tm9JVIU6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pihNur6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uJnB95ja, 1, m, &cVar_uJnB95ja_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_uJnB95ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BNU8oJ3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GnME5xxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfrTXeQ9, HV_BINOP_MULTIPLY, 1, m, &cBinop_DfrTXeQ9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dfCHtVBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GnME5xxH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0PJWTOqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GRDPGknY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GRDPGknY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pLO4qL2, HV_BINOP_MULTIPLY, 1, m, &cBinop_4pLO4qL2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3iljHgBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_48ti68RV, HV_BINOP_MULTIPLY, 1, m, &cBinop_48ti68RV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b3mLqkkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3iljHgBe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b8f3otT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nU6pyaFl, HV_BINOP_MULTIPLY, 1, m, &cBinop_nU6pyaFl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_CpxeQCOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kMnxpKqU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kMnxpKqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZJcGSpl2, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZJcGSpl2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Gyu3ed7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pn72d9yO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_oqJC0oPC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3ZlXUxRc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_IR1LsEeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dAiKL9Y7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ry8kT2ED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_tCjeJHIE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rVS41Yya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QvvT58wU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_vlIAVd2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MGYvkbTd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MVpgbtiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AtX8rZ0M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_FnHfxwp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CG2CqRY4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_tm9JVIU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZovEoxBq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZovEoxBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW68Yzkm, HV_BINOP_MULTIPLY, 1, m, &cBinop_yW68Yzkm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yW68Yzkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WKGlhFJj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WKGlhFJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FnHfxwp9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BNU8oJ3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gMnpJI59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gMnpJI59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QAoM7Hzf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wDcUG9H6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UMKCrMUA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vEiXdiJv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TW269aDs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T589kPHP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DfrTXeQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fU3CNjN6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4pLO4qL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8dp9PUIV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_48ti68RV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VU2H8fiX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nU6pyaFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYmyvrTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZJcGSpl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KErgEiDz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_nWr1rf7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IR1LsEeQ, 1, m, &cVar_IR1LsEeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PHC2WMkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gyu3ed7N, 0, m, &cVar_Gyu3ed7N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T589kPHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DfrTXeQ9, HV_BINOP_MULTIPLY, 0, m, &cBinop_DfrTXeQ9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UMKCrMUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nU6pyaFl, HV_BINOP_MULTIPLY, 0, m, &cBinop_nU6pyaFl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TW269aDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pLO4qL2, HV_BINOP_MULTIPLY, 0, m, &cBinop_4pLO4qL2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wDcUG9H6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZJcGSpl2, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZJcGSpl2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vEiXdiJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_48ti68RV, HV_BINOP_MULTIPLY, 0, m, &cBinop_48ti68RV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QAoM7Hzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_3ZlXUxRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uJnB95ja, 0, m, &cVar_uJnB95ja_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pn72d9yO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IR1LsEeQ, 0, m, &cVar_IR1LsEeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Wy4uVmwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rDS9Bo1F, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hhNQQH3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ikZ0xpg0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2u4YTo7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pHEvOFrb, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TUbUW65h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jJRJyVCy, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xs63Nny5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QmMeuvWa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_QmMeuvWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOLgTRBf, HV_BINOP_DIVIDE, 1, m, &cBinop_gOLgTRBf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ToDUpL7N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_7rCCnmsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_bzECOood_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TBLUwmnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7rCCnmsY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bzECOood_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOLgTRBf, HV_BINOP_DIVIDE, 0, m, &cBinop_gOLgTRBf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ToDUpL7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TBLUwmnO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gOLgTRBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1o5juWz0, HV_BINOP_MULTIPLY, 1, m, &cBinop_1o5juWz0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1o5juWz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yf5Qij6x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SXuROyP4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_NAfw3msE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bBMBrmX9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_YYUC5U0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xl9Uux2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YFmiOjVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2iqj5KA1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2iqj5KA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1o5juWz0, HV_BINOP_MULTIPLY, 0, m, &cBinop_1o5juWz0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5YhEiJtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_MKn4Rvhc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MKn4Rvhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ntOG1cIL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4eGl5lNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I4EeEwBX, HV_BINOP_MULTIPLY, 1, m, &cBinop_I4EeEwBX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A2r132x0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HqFtgHEX, 1, m, &cVar_HqFtgHEX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AOB5gMwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hv1WkjrR, HV_BINOP_MULTIPLY, 1, m, &cBinop_hv1WkjrR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YKttvGA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vSLK6hjn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vSLK6hjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEmo62t0, HV_BINOP_MULTIPLY, 1, m, &cBinop_KEmo62t0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_HqFtgHEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K9bxcrLo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_HdTFQ98W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdQFjbsK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_YFmiOjVu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W5ctrXmk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_VxoMEVYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5YhEiJtx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SXuROyP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_YYUC5U0I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Yf5Qij6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NAfw3msE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_bBMBrmX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CwqP83Hc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xl9Uux2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WNA0hP8P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4y5Hi63Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m5v7J3kl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ntOG1cIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HJJQGnv6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HJJQGnv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EsKJhWfz, HV_BINOP_MULTIPLY, 1, m, &cBinop_EsKJhWfz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EsKJhWfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oKyrNrW4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oKyrNrW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4y5Hi63Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_K9bxcrLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_922KP9R7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_922KP9R7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vZdmbLMo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QbGC5puk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OsgKGfrT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IGmN5G4V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ijgpign6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wy4uVmwL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I4EeEwBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhNQQH3r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hv1WkjrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2u4YTo7p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KEmo62t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TUbUW65h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_dlmBocN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VxoMEVYc, 1, m, &cVar_VxoMEVYc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZhDFr3Al_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HdTFQ98W, 0, m, &cVar_HdTFQ98W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JdQFjbsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VxoMEVYc, 0, m, &cVar_VxoMEVYc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_W5ctrXmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HqFtgHEX, 0, m, &cVar_HqFtgHEX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OsgKGfrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I4EeEwBX, HV_BINOP_MULTIPLY, 0, m, &cBinop_I4EeEwBX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QbGC5puk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hv1WkjrR, HV_BINOP_MULTIPLY, 0, m, &cBinop_hv1WkjrR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_IGmN5G4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ijgpign6, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ijgpign6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vZdmbLMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEmo62t0, HV_BINOP_MULTIPLY, 0, m, &cBinop_KEmo62t0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dYOXKN1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_acctVbjZ, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Oi05tnEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mrQv5wUh, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_b1SPPdhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dCVuU4pg, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yVIUoALM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TXuHgU9H, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_wiW5EQHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yFI4FULV, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pZe9A2ib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_njIa179W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_njIa179W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Rb9wcFp, HV_BINOP_DIVIDE, 1, m, &cBinop_2Rb9wcFp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VZoeQJU1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_N4jtX9GJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_maivwI7K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MIO26cw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_N4jtX9GJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_maivwI7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Rb9wcFp, HV_BINOP_DIVIDE, 0, m, &cBinop_2Rb9wcFp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VZoeQJU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MIO26cw9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2Rb9wcFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPNZcKBT, HV_BINOP_MULTIPLY, 1, m, &cBinop_pPNZcKBT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pPNZcKBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VQJ9xJmC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KWcrO3qX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_4O4UnjrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w4rFOv43_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_tg9WF36H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n8WFWnfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ousol4Gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9vCR8E87_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9vCR8E87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPNZcKBT, HV_BINOP_MULTIPLY, 0, m, &cBinop_pPNZcKBT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NP3NPwei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Ktokpyk0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ktokpyk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6coLhDlF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xmazoU7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zRk5yJE8, HV_BINOP_MULTIPLY, 1, m, &cBinop_zRk5yJE8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8lx3UOlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6kdEMgOL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6kdEMgOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xmazoU7O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VSeUroNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kqHV7ESi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kqHV7ESi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nqi1KzBa, HV_BINOP_MULTIPLY, 1, m, &cBinop_Nqi1KzBa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TAny3fRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n4XYx1A0, HV_BINOP_MULTIPLY, 1, m, &cBinop_n4XYx1A0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J2fyjlPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_s6ZaAAsP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_s6ZaAAsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TAny3fRg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rHHp17kO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5f2mZvrA, 1, m, &cVar_5f2mZvrA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0QyvPLZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0iI1Dz6W, HV_BINOP_MULTIPLY, 1, m, &cBinop_0iI1Dz6W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_s8gX1rXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WOcOTCEO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WOcOTCEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aizKiMHC, HV_BINOP_MULTIPLY, 1, m, &cBinop_aizKiMHC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5f2mZvrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GXsrvpX5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Hir1HgGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ESCdIfZ5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ousol4Gw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YfG93WQ4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_YTMVV1EU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NP3NPwei_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VQJ9xJmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_4O4UnjrW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KWcrO3qX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_tg9WF36H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_w4rFOv43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PV5DvH7u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_n8WFWnfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jLxnxVly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_L2lezYfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_51bxUicd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_6coLhDlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_46JjGxXB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_46JjGxXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T5hyW49H, HV_BINOP_MULTIPLY, 1, m, &cBinop_T5hyW49H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_T5hyW49H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qf0wCruc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qf0wCruc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L2lezYfG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_GXsrvpX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Mmtz7DpU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Mmtz7DpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I17oYNnE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ypz4nxRw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HwlqUFoh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eptXMG6j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y6CUrBlc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U891UbDz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zRk5yJE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dYOXKN1f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Nqi1KzBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oi05tnEL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_n4XYx1A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b1SPPdhV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0iI1Dz6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yVIUoALM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aizKiMHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wiW5EQHr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_qBaR4t6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hir1HgGj, 0, m, &cVar_Hir1HgGj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OplcQfKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YTMVV1EU, 1, m, &cVar_YTMVV1EU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_U891UbDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zRk5yJE8, HV_BINOP_MULTIPLY, 0, m, &cBinop_zRk5yJE8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HwlqUFoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0iI1Dz6W, HV_BINOP_MULTIPLY, 0, m, &cBinop_0iI1Dz6W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_y6CUrBlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nqi1KzBa, HV_BINOP_MULTIPLY, 0, m, &cBinop_Nqi1KzBa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ypz4nxRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aizKiMHC, HV_BINOP_MULTIPLY, 0, m, &cBinop_aizKiMHC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_eptXMG6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n4XYx1A0, HV_BINOP_MULTIPLY, 0, m, &cBinop_n4XYx1A0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_I17oYNnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_YfG93WQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5f2mZvrA, 0, m, &cVar_5f2mZvrA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ESCdIfZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YTMVV1EU, 0, m, &cVar_YTMVV1EU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mnzmgw6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gjvnLLey, 1, m, &cIf_gjvnLLey_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_By0Boy40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oKNxUuc2, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LS54xZO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_By0Boy40_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Mt7E5vaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gjvnLLey, 0, m, &cIf_gjvnLLey_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Iu9AgWy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AHitZZVC, HV_BINOP_DIVIDE, 0, m, &cBinop_AHitZZVC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_rlEiWYOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gx4FRYrZ, HV_BINOP_DIVIDE, 1, m, &cBinop_Gx4FRYrZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AHitZZVC, HV_BINOP_DIVIDE, 1, m, &cBinop_AHitZZVC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_a57zP4yY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GMYCiVww, HV_BINOP_DIVIDE, 0, m, &cBinop_GMYCiVww_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_CUPHz1o3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GMYCiVww, HV_BINOP_DIVIDE, 1, m, &cBinop_GMYCiVww_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oTPVyarj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gx4FRYrZ, HV_BINOP_DIVIDE, 0, m, &cBinop_Gx4FRYrZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rD33oI0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iu9AgWy0, 0, m, &cVar_Iu9AgWy0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Q7K1cmWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rlEiWYOE, 0, m, &cVar_rlEiWYOE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gx4FRYrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_a57zP4yY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AHitZZVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_CUPHz1o3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GMYCiVww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_OBKiRlwu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ANfg078O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_xnEIv2mf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KFUjI7dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_0YB3hUNV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OBKiRlwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KFUjI7dp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0YB3hUNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_ANfg078O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xnEIv2mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i2TUb72w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_NTspab9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gmb4wHUG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_IpCVdNQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ull3y40F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_LVdlUR0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TQNpYX2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_kOWJGR72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BTAoB2wr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_x0bGZiPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QYrQWxdR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_0ZRA9uMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MFY8hOgM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_9AIOH88U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v11sNCeV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_qWcZ6Pbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YYw932ss_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_VyAfERtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ji7aS9eH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_UwWAu8kU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NopDkuPO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_mQyeqBdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AWh8tJZi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Id55EDy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sknzFhwi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uWzj1hcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_otlAmnSD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_otlAmnSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_lXcFKYBf, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_l9UBqvsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WoPtS7bx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_WoPtS7bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DAMloknp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_KTAmkUaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OLgn611j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_WnQ50BH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5heh7IEb_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_v2tA4D1T, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DAMloknp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VdJTyCeg, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OLgn611j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WnQ50BH9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5heh7IEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZvRcfCFh, m);
}

void Heavy_WSTD_FL3NGR::cMsg_2pLo1N2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4GNrfMLj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4GNrfMLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0ZvHKDRz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_39szFUPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3iYbhJKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_v5N0AbAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_h9eRBTmW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vsAeVip9, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0ZvHKDRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EKYTXHPE, m);
}

void Heavy_WSTD_FL3NGR::cMsg_3iYbhJKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v5N0AbAb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_h9eRBTmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CTOwbg1i, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CuwwtvqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_scpjjYYd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_scpjjYYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_wZy7lcnH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Xh1PTSW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k4icA4b7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_3ESGrcyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tDOeK1y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wZy7lcnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jsUFOw3S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jsUFOw3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gu5MgQjS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zpkWN3M3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zpkWN3M3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H5gGXdYp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_Gu5MgQjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3pD6R71y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3pD6R71y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bCuS6kdX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_H5gGXdYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jDWwHCVs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jDWwHCVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_651LNN9N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bCuS6kdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Xh1PTSW2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_651LNN9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3ESGrcyE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_O1Q6KZeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_oo7UDBWi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oo7UDBWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vgJHDjQy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_C9VOM0u2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SWVNAdz6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_SWVNAdz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NKrJtW7J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_0Y5JvreQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0Y5JvreQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_L7D68aJ3, 0, m, &cDelay_L7D68aJ3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Y5JvreQ, 0, m, &cDelay_0Y5JvreQ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WUbZ1xYw, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_L7D68aJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L7D68aJ3, m);
  cMsg_5O9ZkWXZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_nnHQCmiT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_MweLPML6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_YCpXZ1Y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eONAlXM3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_YEX68X0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NiLdVa2q_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Y5JvreQ, 2, m, &cDelay_0Y5JvreQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OvhvdaGk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eONAlXM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YEX68X0O, 0, m, &hTable_YEX68X0O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NKrJtW7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_YCpXZ1Y0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5O9ZkWXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YEX68X0O, 0, m, &hTable_YEX68X0O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OvhvdaGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Y5JvreQ, 0, m, &cDelay_0Y5JvreQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NiLdVa2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_L7D68aJ3, 2, m, &cDelay_L7D68aJ3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MweLPML6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_WUbZ1xYw, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_r1mdD0IR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_um3zdPqP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_um3zdPqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WYyWwe6h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_Xgzyjqaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xgzyjqaz, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N8LUAEbi, 0, m, &cDelay_N8LUAEbi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xgzyjqaz, 0, m, &cDelay_Xgzyjqaz_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gzEULu5U, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_N8LUAEbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N8LUAEbi, m);
  cMsg_XUxqUE7W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_X1nURSIJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_5sj25ZFG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_QPBE2ugs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ek7voxLu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_NELrlLWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M6QWJ1ZF_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xgzyjqaz, 2, m, &cDelay_Xgzyjqaz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XqDSMqLD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Ek7voxLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_NELrlLWL, 0, m, &hTable_NELrlLWL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WYyWwe6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_QPBE2ugs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XUxqUE7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_NELrlLWL, 0, m, &hTable_NELrlLWL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XqDSMqLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xgzyjqaz, 0, m, &cDelay_Xgzyjqaz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_M6QWJ1ZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_N8LUAEbi, 2, m, &cDelay_N8LUAEbi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5sj25ZFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gzEULu5U, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_ohQIrNam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpFH38Zx, HV_BINOP_MULTIPLY, 0, m, &cBinop_VpFH38Zx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7BRYO5IA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pOjXLhy5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_pOjXLhy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qtCf9aTN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VpFH38Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_z6m0J6SJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gVU94QLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VpFH38Zx, HV_BINOP_MULTIPLY, 1, m, &cBinop_VpFH38Zx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qtCf9aTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gVU94QLP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_z6m0J6SJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4qu1EMpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4qu1EMpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9raz33iD_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ACQIkKjG, m);
}

void Heavy_WSTD_FL3NGR::cBinop_9raz33iD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Cy0tcwIZ, m);
}

void Heavy_WSTD_FL3NGR::cVar_ReNS35jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XD0LBsXw, HV_BINOP_MULTIPLY, 0, m, &cBinop_XD0LBsXw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_L7kpNOn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ICAI9uwL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ICAI9uwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J6Rz1DHt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_XD0LBsXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cBURnO4s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_op6gUeX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XD0LBsXw, HV_BINOP_MULTIPLY, 1, m, &cBinop_XD0LBsXw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J6Rz1DHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_op6gUeX8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cBURnO4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3lysPRGO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3lysPRGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CrzDIH7A_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_a4UpEMO1, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CrzDIH7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4nSKrMYS, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vgJHDjQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G3plSuL4, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_VoEkMIvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_diPsrOQr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8QBYJziv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kM7GDk8h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tlKCuLK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_VoEkMIvn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BJDnd6x2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_e1QhWEmR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_e1QhWEmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y0QZO59Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_Y0QZO59Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kM7GDk8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_BJDnd6x2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Y0QZO59Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nvKtF1Bp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_diPsrOQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y0QZO59Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_Y0QZO59Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nvKtF1Bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xGIFBky0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_NOYcHtUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_DVJoWkB1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DVJoWkB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8QBYJziv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tlKCuLK9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ZpbIFl5T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_buiqE0Ht, 0, m, &cSlice_buiqE0Ht_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9DOTswHb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_buiqE0Ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Mnta5zhi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Mnta5zhi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_YG0gF8Jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mnta5zhi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Mnta5zhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6eE83OJB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_9DOTswHb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r8C0ShuO, 0, m, &cSlice_r8C0ShuO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EINqWnsc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_r8C0ShuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J3KWwvap_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J3KWwvap_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0S2r3TPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J3KWwvap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_J3KWwvap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tBUwCYiZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EINqWnsc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FSr44Etu, 0, m, &cSlice_FSr44Etu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FzkyRLyG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_FSr44Etu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P5DJ0eU2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P5DJ0eU2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZiuUIdhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P5DJ0eU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_P5DJ0eU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iJjoeJ4m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_FzkyRLyG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XYMyh79I, 0, m, &cSlice_XYMyh79I_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_XYMyh79I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PQSpKiVn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PQSpKiVn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_3LkfoZRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PQSpKiVn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_PQSpKiVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xrqz6fxo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_k4icA4b7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KyJADjIw, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_tDOeK1y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UQJvqx8y, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_O8PK91As_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KVvuKnBQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KVvuKnBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Raj7ZeNN, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_3I2OJWNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2pSSV5DP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_2pSSV5DP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_PX7OgAxq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_mBiG9hvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eG2mMCQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_6xn5SGf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Q1pnp4P7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6qaoWCeX, m);
}

void Heavy_WSTD_FL3NGR::cBinop_PX7OgAxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oNWYSEWR, m);
}

void Heavy_WSTD_FL3NGR::cMsg_eG2mMCQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6xn5SGf6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q1pnp4P7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Rbda3ll1, m);
}

void Heavy_WSTD_FL3NGR::cMsg_AekHwrxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GuG0GfBP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_GuG0GfBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_8XgMuOW9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_55ZE1n27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YyAlkeB4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_wmrvysZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Hj7d9pd8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Wfj17syK, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8XgMuOW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_I6w7OXmC, m);
}

void Heavy_WSTD_FL3NGR::cMsg_YyAlkeB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wmrvysZt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Hj7d9pd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SbSna2LP, m);
}

void Heavy_WSTD_FL3NGR::cBinop_UsU8hg6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_w8HI2URj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w8HI2URj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_OtjRMzdY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_QdXShRBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kqBaI36k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_3ugizoRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qmxxrRyF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OtjRMzdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fjUzggP6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fjUzggP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ovKxikqQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DDkWuYkZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DDkWuYkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TzZIVMXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ovKxikqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_H06xPRA5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_H06xPRA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UMuCleq3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_TzZIVMXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_g53YSk35_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g53YSk35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bWif8eNW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UMuCleq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_QdXShRBt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bWif8eNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3ugizoRx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hyHrPZ2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WzCUwBHM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WzCUwBHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XRyAcrUS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Yj9TVBQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lVOgw1aE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_lVOgw1aE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ns1dWL5S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_BEdsWSHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BEdsWSHR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WUeQDQLO, 0, m, &cDelay_WUeQDQLO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BEdsWSHR, 0, m, &cDelay_BEdsWSHR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RXxH6vd1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_WUeQDQLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WUeQDQLO, m);
  cMsg_ss6wtciQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ujSHadrX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_nbVU7s10_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_y16OtAA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ByHnm45M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_Pb13gwnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3wbtGarm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BEdsWSHR, 2, m, &cDelay_BEdsWSHR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YL77jnx5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ByHnm45M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Pb13gwnA, 0, m, &hTable_Pb13gwnA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ns1dWL5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_y16OtAA1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ss6wtciQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Pb13gwnA, 0, m, &hTable_Pb13gwnA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YL77jnx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BEdsWSHR, 0, m, &cDelay_BEdsWSHR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3wbtGarm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WUeQDQLO, 2, m, &cDelay_WUeQDQLO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nbVU7s10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RXxH6vd1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_nZUmeqTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3MwlZch2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_3MwlZch2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NK3Kewba_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_N5ZMvK5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N5ZMvK5V, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NDRj8Dfo, 0, m, &cDelay_NDRj8Dfo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N5ZMvK5V, 0, m, &cDelay_N5ZMvK5V_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mskV5GBr, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_NDRj8Dfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NDRj8Dfo, m);
  cMsg_SRFJe2dt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_KyTh4GQJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7h642m6T_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_S5bwihE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wYRfhJrM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_591hj3AU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tudnDsr0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N5ZMvK5V, 2, m, &cDelay_N5ZMvK5V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i0sRumF0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wYRfhJrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_591hj3AU, 0, m, &hTable_591hj3AU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NK3Kewba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_S5bwihE8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SRFJe2dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_591hj3AU, 0, m, &hTable_591hj3AU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_i0sRumF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N5ZMvK5V, 0, m, &cDelay_N5ZMvK5V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tudnDsr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_NDRj8Dfo, 2, m, &cDelay_NDRj8Dfo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7h642m6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mskV5GBr, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_uiuet9yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TnZPvGcW, HV_BINOP_MULTIPLY, 0, m, &cBinop_TnZPvGcW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZMPFEkmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_j876muPf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_j876muPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OeuA8WL2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TnZPvGcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_gMQeSMii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_piUTyvBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TnZPvGcW, HV_BINOP_MULTIPLY, 1, m, &cBinop_TnZPvGcW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OeuA8WL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_piUTyvBy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gMQeSMii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LvPZtyqb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LvPZtyqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wJ98gpWg_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Fkpb8h1q, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wJ98gpWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zNyL3kzj, m);
}

void Heavy_WSTD_FL3NGR::cVar_1J2aN6ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sc5t5v3H, HV_BINOP_MULTIPLY, 0, m, &cBinop_sc5t5v3H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_21JC90V9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NNCVOBvA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_NNCVOBvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BKY9BOJ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_sc5t5v3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_p56yco88_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VaPYyJtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sc5t5v3H, HV_BINOP_MULTIPLY, 1, m, &cBinop_sc5t5v3H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BKY9BOJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VaPYyJtH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p56yco88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fGHVCsiT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fGHVCsiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wsK9HQb3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zv5ujA3e, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wsK9HQb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6GZ4ThXZ, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XRyAcrUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CQ6gJjcR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_dcYbubcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_1xWHxL9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xIHmsfma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tZS1lyYd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VUISbE1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_dcYbubcs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Nk6m0LFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hZNvnRPG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hZNvnRPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j7RoCvy8, HV_BINOP_MULTIPLY, 1, m, &cBinop_j7RoCvy8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tZS1lyYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Nk6m0LFM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_j7RoCvy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JFA7ygL9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1xWHxL9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j7RoCvy8, HV_BINOP_MULTIPLY, 0, m, &cBinop_j7RoCvy8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JFA7ygL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zj4qC4ub, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_xgJl6FVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_ZwXejT48_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZwXejT48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xIHmsfma_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VUISbE1V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2nquRkWT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1ddgrRnW, 0, m, &cSlice_1ddgrRnW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PvC8hSsO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_1ddgrRnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LXfiXX15_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LXfiXX15_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_WhcEUR5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LXfiXX15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LXfiXX15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JlG3nc7E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_PvC8hSsO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZCaZlIZ2, 0, m, &cSlice_ZCaZlIZ2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4uWgwkpG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ZCaZlIZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_djfvuw5z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_djfvuw5z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_FL3qCSbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_djfvuw5z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_djfvuw5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ecvStRd5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_4uWgwkpG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vb0lWCzG, 0, m, &cSlice_vb0lWCzG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_riD3otgJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_vb0lWCzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yD4jvJm3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yD4jvJm3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_rn5pIPkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yD4jvJm3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_yD4jvJm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GSVONXXY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_riD3otgJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U1N4d5o2, 0, m, &cSlice_U1N4d5o2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_U1N4d5o2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LsMu1ma5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LsMu1ma5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_prdf5GU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LsMu1ma5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LsMu1ma5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rvD3vCXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_kqBaI36k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B4zEHYRA, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_qmxxrRyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FbWgKnbR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_xCKiIlZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Dhe7FjzM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dhe7FjzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Lh6tQE6Z, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_y2CCMvyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4txICiW1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_4txICiW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_w3QV0KbC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_A3xf6yci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nIEOfdW4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_0r3yjLyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FxTJPJGV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8g6uI2dG, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w3QV0KbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_A4MscM5E, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nIEOfdW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0r3yjLyw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FxTJPJGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_X8B2vEvx, m);
}

void Heavy_WSTD_FL3NGR::cMsg_uUVJbtIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C1NCs6JR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_C1NCs6JR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hogGwDiE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_TUed2Hhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UaLy1wow_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_A67WKOpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eHynWw8J_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ddighjGB, m);
}

void Heavy_WSTD_FL3NGR::cBinop_hogGwDiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UN65DTka, m);
}

void Heavy_WSTD_FL3NGR::cMsg_UaLy1wow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_A67WKOpk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eHynWw8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9u4ry4Xv, m);
}

void Heavy_WSTD_FL3NGR::cBinop_CnBdxCoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7HyQNGpq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7HyQNGpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_nsrR4HrJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_nSOLO4Cp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SYTVsvlu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_AgmDyCfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HKLu4MEs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nsrR4HrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NKGPfILM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NKGPfILM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gYwef0MS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zN96dFDP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gYwef0MS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VfZkrnF1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zN96dFDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OGX0vVqE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_VfZkrnF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FDvqr1PQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OGX0vVqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lHbqNo9U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lHbqNo9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_M4z0anvv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FDvqr1PQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_nSOLO4Cp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M4z0anvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_AgmDyCfH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Oa4hYFJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LBpc4HfG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LBpc4HfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTh3H1my_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ifphqTLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LKNukl1s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_LKNukl1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_EYJdsBZ5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_3XpKjRe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3XpKjRe8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpUV2KP9, 0, m, &cDelay_DpUV2KP9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3XpKjRe8, 0, m, &cDelay_3XpKjRe8_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_I85rRx8m, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_DpUV2KP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DpUV2KP9, m);
  cMsg_Zu6GMO1J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_1AGcD1il_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_u7SYvwC3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_pjHSkYAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7pWuwYvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_GcX4eLjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mcFF5h5I_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3XpKjRe8, 2, m, &cDelay_3XpKjRe8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d7I9QHyR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7pWuwYvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GcX4eLjS, 0, m, &hTable_GcX4eLjS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EYJdsBZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_pjHSkYAi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Zu6GMO1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GcX4eLjS, 0, m, &hTable_GcX4eLjS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_d7I9QHyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3XpKjRe8, 0, m, &cDelay_3XpKjRe8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mcFF5h5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_DpUV2KP9, 2, m, &cDelay_DpUV2KP9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_u7SYvwC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_I85rRx8m, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dNW3W1eM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_p3pTETF6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_p3pTETF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_88RJVtsR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_clPhCfEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_clPhCfEg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zuAj49Kv, 0, m, &cDelay_zuAj49Kv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_clPhCfEg, 0, m, &cDelay_clPhCfEg_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dYXTzyMc, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_zuAj49Kv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zuAj49Kv, m);
  cMsg_wKW3nV3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ZWq2IJWW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_1kwJIqOl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_baZ4Redq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qye21G6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_nTVoy4wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQbgnCIp_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_clPhCfEg, 2, m, &cDelay_clPhCfEg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d88466Zc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qye21G6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_nTVoy4wi, 0, m, &hTable_nTVoy4wi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_88RJVtsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_baZ4Redq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wKW3nV3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_nTVoy4wi, 0, m, &hTable_nTVoy4wi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_d88466Zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_clPhCfEg, 0, m, &cDelay_clPhCfEg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OQbgnCIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_zuAj49Kv, 2, m, &cDelay_zuAj49Kv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1kwJIqOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_dYXTzyMc, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_e2gxpPZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ohjh7BCT, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ohjh7BCT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_z0n43h2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I4SpUz4w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_I4SpUz4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2cjwceuf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ohjh7BCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DXB1prCo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_70Rayghp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ohjh7BCT, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ohjh7BCT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2cjwceuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_70Rayghp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DXB1prCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gank5nP1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gank5nP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NdZ7nWcv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AgamUPlM, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NdZ7nWcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_z0VlazzF, m);
}

void Heavy_WSTD_FL3NGR::cVar_tKp3Gf3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZSVqgQqO, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZSVqgQqO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_COb0AZMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JkwH0uof_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_JkwH0uof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HbbmLtO6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZSVqgQqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_iXyuY0vS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JV0STaNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZSVqgQqO, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZSVqgQqO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HbbmLtO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JV0STaNb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iXyuY0vS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8Efkarbk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8Efkarbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_r3eUU8nT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GLNZcCTg, m);
}

void Heavy_WSTD_FL3NGR::cBinop_r3eUU8nT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_30yIHaW8, m);
}

void Heavy_WSTD_FL3NGR::cMsg_DTh3H1my_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XDF2IpD5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_BSafmaZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_Kf56WFuV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_osq9KGbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_BSafmaZW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_s91zd5ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GsktmeMS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uRrJvtXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vZXJQ15y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vZXJQ15y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F6cucBA7, HV_BINOP_MULTIPLY, 1, m, &cBinop_F6cucBA7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GsktmeMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_uRrJvtXs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F6cucBA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKGBmJu2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Kf56WFuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F6cucBA7, HV_BINOP_MULTIPLY, 0, m, &cBinop_F6cucBA7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZKGBmJu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XA0p8U5G, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_0UfDX4Q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_cTyZjkyn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cTyZjkyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s91zd5ik_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_osq9KGbj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_fN6fi6I6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1rKROwRG, 0, m, &cSlice_1rKROwRG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2b0uj0mL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_1rKROwRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WRWxWKNp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WRWxWKNp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_2jH3Ge2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WRWxWKNp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_WRWxWKNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ho1fumo0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2b0uj0mL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lbpyAnUM, 0, m, &cSlice_lbpyAnUM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dxR3fX8s_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_lbpyAnUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VduzTv4V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VduzTv4V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_4ctkH2zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VduzTv4V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_VduzTv4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HxRAA8Dl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_dxR3fX8s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mrGnehtx, 0, m, &cSlice_mrGnehtx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vkjUqyMn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_mrGnehtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GH9ZbPAt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GH9ZbPAt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_m37Gwzyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GH9ZbPAt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_GH9ZbPAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Frj0S6ty_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vkjUqyMn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PCuoGzHX, 0, m, &cSlice_PCuoGzHX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_PCuoGzHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P5mMK8kn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P5mMK8kn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_L7BFXkWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P5mMK8kn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_P5mMK8kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VZENmdvU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SYTVsvlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_weiJAgS1, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HKLu4MEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hxyd87Bh, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_LFj09Tsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xxMEvDoX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Xj7MZwzd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_3I6VLaru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xxMEvDoX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Xj7MZwzd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_pZqbtaaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xxMEvDoX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Xj7MZwzd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_u9iDglzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xxMEvDoX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Xj7MZwzd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_i2TUb72w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xxMEvDoX_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Xj7MZwzd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TfPuzmjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4fnJEGkY, 0, m, &cVar_4fnJEGkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sI3xX3Ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_0XNZRoO8, 0, m, &cVar_0XNZRoO8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uq7psq9M, 0, m, &cVar_uq7psq9M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_58wvUsGz, 0, m, &cVar_58wvUsGz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BTAoB2wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ZpbIFl5T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Gmb4wHUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ZpbIFl5T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Ull3y40F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ZpbIFl5T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_TQNpYX2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ZpbIFl5T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_jhxfzJLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kOWJGR72, 0, m, &cVar_kOWJGR72_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eJbbemoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NTspab9x, 0, m, &cVar_NTspab9x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RPjJlUbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LVdlUR0y, 0, m, &cVar_LVdlUR0y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YYw932ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2nquRkWT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QYrQWxdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2nquRkWT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MFY8hOgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2nquRkWT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_v11sNCeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2nquRkWT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_7nfukeB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qWcZ6Pbj, 0, m, &cVar_qWcZ6Pbj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jsSL94KA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x0bGZiPl, 0, m, &cVar_x0bGZiPl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NjFrIzdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9AIOH88U, 0, m, &cVar_9AIOH88U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sknzFhwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_fN6fi6I6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ji7aS9eH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_fN6fi6I6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_NopDkuPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_fN6fi6I6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_AWh8tJZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_fN6fi6I6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_YkYck5X8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Id55EDy2, 0, m, &cVar_Id55EDy2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HRrC2PJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VyAfERtk, 0, m, &cVar_VyAfERtk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HYdNplJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mQyeqBdi, 0, m, &cVar_mQyeqBdi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7YyieX0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0XNZRoO8, 0, m, &cVar_0XNZRoO8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3RFqTazV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uq7psq9M, 0, m, &cVar_uq7psq9M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_pgnjfCxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_58wvUsGz, 0, m, &cVar_58wvUsGz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_oBqp5vPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hWPv1W4m, 0, m, &cVar_hWPv1W4m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SLlnmlqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XbUO6IUf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_spLvjely_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9KlsZH2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kp4o5CPT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CD4wcyP8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mRlkL17a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_nV7rlx1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZXWIEURj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zoTcqkoY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tUbw4yIi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RM8cinzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6KfxnDJD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zOIQzX8L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NlYqPaPH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_PEbgA7Y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JMieYlC2_sendMessage(_c, 0, m);
  cMsg_w4y0XgpC_sendMessage(_c, 0, m);
  cMsg_IdHBvESd_sendMessage(_c, 0, m);
  cMsg_00Mol4mX_sendMessage(_c, 0, m);
  cMsg_xs63Nny5_sendMessage(_c, 0, m);
  cMsg_pZe9A2ib_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YCQvZK64, 0, m, &cVar_YCQvZK64_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hWPv1W4m, 0, m, &cVar_hWPv1W4m_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2UUI0sGs, 0, m, &cVar_2UUI0sGs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Gyu3ed7N, 0, m, &cVar_Gyu3ed7N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HdTFQ98W, 0, m, &cVar_HdTFQ98W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hir1HgGj, 0, m, &cVar_Hir1HgGj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BnQt7NE6, 0, m, &cVar_BnQt7NE6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WAcihRK0, 0, m, &cVar_WAcihRK0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9LXEN1h6, 0, m, &cVar_9LXEN1h6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y9BDc9v5, 0, m, &cVar_Y9BDc9v5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6rZSpp4N, 0, m, &cVar_6rZSpp4N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_770CxnRt, 0, m, &cVar_770CxnRt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QOQAFDEc, 0, m, &cVar_QOQAFDEc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Bzxq42QR, 0, m, &cVar_Bzxq42QR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5sZw0qmS, 0, m, &cVar_5sZw0qmS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tx32fSdT, 0, m, &cVar_tx32fSdT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_axa9CS5t, 0, m, &cVar_axa9CS5t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b2v8ifpP, 0, m, &cVar_b2v8ifpP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_29Pp5Vjl, 0, m, &cVar_29Pp5Vjl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BDGlafDG, 0, m, &cVar_BDGlafDG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hFRSmr2P, 0, m, &cVar_hFRSmr2P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wVPRrwdQ, 0, m, &cVar_wVPRrwdQ_sendMessage);
  cMsg_7BRYO5IA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ohQIrNam, 0, m, &cVar_ohQIrNam_sendMessage);
  cMsg_L7kpNOn4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ReNS35jq, 0, m, &cVar_ReNS35jq_sendMessage);
  cMsg_ZMPFEkmV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uiuet9yv, 0, m, &cVar_uiuet9yv_sendMessage);
  cMsg_21JC90V9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1J2aN6ug, 0, m, &cVar_1J2aN6ug_sendMessage);
  cMsg_z0n43h2q_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_e2gxpPZD, 0, m, &cVar_e2gxpPZD_sendMessage);
  cMsg_COb0AZMt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tKp3Gf3x, 0, m, &cVar_tKp3Gf3x_sendMessage);
  cMsg_C9VOM0u2_sendMessage(_c, 0, m);
  cMsg_r1mdD0IR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YG0gF8Jq, 0, m, &cVar_YG0gF8Jq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0S2r3TPR, 0, m, &cVar_0S2r3TPR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZiuUIdhn, 0, m, &cVar_ZiuUIdhn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3LkfoZRa, 0, m, &cVar_3LkfoZRa_sendMessage);
  cMsg_Yj9TVBQ5_sendMessage(_c, 0, m);
  cMsg_nZUmeqTW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WhcEUR5q, 0, m, &cVar_WhcEUR5q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FL3qCSbI, 0, m, &cVar_FL3qCSbI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rn5pIPkS, 0, m, &cVar_rn5pIPkS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_prdf5GU1, 0, m, &cVar_prdf5GU1_sendMessage);
  cMsg_ifphqTLq_sendMessage(_c, 0, m);
  cMsg_dNW3W1eM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2jH3Ge2t, 0, m, &cVar_2jH3Ge2t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4ctkH2zp, 0, m, &cVar_4ctkH2zp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m37Gwzyw, 0, m, &cVar_m37Gwzyw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_L7BFXkWu, 0, m, &cVar_L7BFXkWu_sendMessage);
  cMsg_sI3xX3Ne_sendMessage(_c, 0, m);
  cMsg_TfPuzmjD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KTAmkUaB, 0, m, &cVar_KTAmkUaB_sendMessage);
  cMsg_l9UBqvsl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_39szFUPV, 0, m, &cVar_39szFUPV_sendMessage);
  cMsg_2pLo1N2u_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mBiG9hvp, 0, m, &cVar_mBiG9hvp_sendMessage);
  cMsg_3I2OJWNL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_55ZE1n27, 0, m, &cVar_55ZE1n27_sendMessage);
  cMsg_AekHwrxO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_A3xf6yci, 0, m, &cVar_A3xf6yci_sendMessage);
  cMsg_y2CCMvyL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TUed2Hhf, 0, m, &cVar_TUed2Hhf_sendMessage);
  cMsg_uUVJbtIc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_C42k7DUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AVdXoHyV, HV_BINOP_MULTIPLY, 0, m, &cBinop_AVdXoHyV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4G3kkZBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wpGyV15J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RfgTgQxy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_co1k4lwl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_N0Y5LcG2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BQz4UCO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rqMQeMfc_sendMessage);
  cMsg_p4j9wUtc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_jGHfDumw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dytzCxah, HV_BINOP_MULTIPLY, 0, m, &cBinop_dytzCxah_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0CvRPipF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_jqJvqi14_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LeeMGnkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yh8xHSVq, HV_BINOP_MULTIPLY, 1, m, &cBinop_yh8xHSVq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iWDRA4uU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ebDwyeRP_sendMessage);
  cMsg_4ItMSslU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_t4jGTr7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PdHysRXi, HV_BINOP_MULTIPLY, 0, m, &cBinop_PdHysRXi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rK7eOatK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ro0c41o4_sendMessage(_c, 0, m);
  cMsg_ACTIxLgi_sendMessage(_c, 0, m);
  cMsg_lYw65POk_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_MD5XiroQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_sNe4EOtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mWIycuIL_sendMessage);
  cMsg_OQlN4eVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_QdF9Rokw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HdTFQ98W, 0, m, &cVar_HdTFQ98W_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VhJrXioN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dlmBocN9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZhDFr3Al_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VT7eUu5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u2cgrONQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0lh1lGLB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TeIEgK5f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Du9Tklha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_csQVm6hz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zD7xPdrx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xJIPdOtC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QKQjqV2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n3uK5lrP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fp6aoMRC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1050jE3l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_MGYvkbTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW68Yzkm, HV_BINOP_MULTIPLY, 0, m, &cBinop_yW68Yzkm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_AtX8rZ0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dfCHtVBd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0PJWTOqg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_b3mLqkkp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_b8f3otT0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_CG2CqRY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pihNur6F_sendMessage);
  cMsg_CpxeQCOt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_CwqP83Hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EsKJhWfz, HV_BINOP_MULTIPLY, 0, m, &cBinop_EsKJhWfz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_WNA0hP8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_AOB5gMwO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_m5v7J3kl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ijgpign6, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ijgpign6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4eGl5lNS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_A2r132x0_sendMessage);
  cMsg_YKttvGA4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_PV5DvH7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T5hyW49H, HV_BINOP_MULTIPLY, 0, m, &cBinop_T5hyW49H_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jLxnxVly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8lx3UOlQ_sendMessage(_c, 0, m);
  cMsg_VSeUroNh_sendMessage(_c, 0, m);
  cMsg_J2fyjlPA_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0QyvPLZT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_51bxUicd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rHHp17kO_sendMessage);
  cMsg_s8gX1rXw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Ddcy27wO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4fnJEGkY, 0, m, &cVar_4fnJEGkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1KKN8OBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_jhxfzJLl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9EKyjO8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eJbbemoc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xLXs2whU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IpCVdNQI, 0, m, &cVar_IpCVdNQI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fIi35fh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_RPjJlUbh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XDWeuqwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7nfukeB4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1ZFud0lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_jsSL94KA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fYxnWyro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0ZRA9uMC, 0, m, &cVar_0ZRA9uMC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jRMNUNW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_NjFrIzdO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7uTtxM34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_YkYck5X8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XnDR7MTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_HRrC2PJF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_eSdfSGWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UwWAu8kU, 0, m, &cVar_UwWAu8kU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_I84xVzkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_HYdNplJo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_iJjoeJ4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_uWzj1hcQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tBUwCYiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NOYcHtUm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xrqz6fxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CuwwtvqK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_6eE83OJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_O1Q6KZeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GSVONXXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_O8PK91As_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ecvStRd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xgJl6FVt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rvD3vCXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UsU8hg6M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JlG3nc7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hyHrPZ2N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Frj0S6ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_xCKiIlZ2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_HxRAA8Dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0UfDX4Q4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VZENmdvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CnBdxCoo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ho1fumo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Oa4hYFJM_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_Yts9sLRc, VOf(Bf0));
    __hv_line_f(&sLine_UK3METDY, VOf(Bf1));
    __hv_line_f(&sLine_PAbm5gEF, VOf(Bf2));
    __hv_line_f(&sLine_fu5JrUYP, VOf(Bf3));
    __hv_line_f(&sLine_efOlMhxY, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_vE17FzQs, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_SODHpIm7, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_q9B6mgFu, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_DY0E1zlG, VOf(Bf1));
    __hv_line_f(&sLine_As661H8n, VOf(Bf0));
    __hv_line_f(&sLine_piehk8eO, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_EmEpAdIl, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_O0CokIOS, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_spP3CPEF, VOf(Bf5));
    __hv_line_f(&sLine_99vFEFgp, VOf(Bf1));
    __hv_line_f(&sLine_R1BWG6Pt, VOf(Bf2));
    __hv_line_f(&sLine_ss0lkXVD, VOf(Bf4));
    __hv_line_f(&sLine_MManfmm5, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_GTkzrrOb, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_3BUoc9Un, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_NYZPxgVl, VOf(Bf6));
    __hv_line_f(&sLine_i3KpzzzT, VOf(Bf2));
    __hv_line_f(&sLine_e9VjjJlT, VOf(Bf1));
    __hv_line_f(&sLine_roUA4zIx, VOf(Bf5));
    __hv_line_f(&sLine_GvjndoCe, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_T6Nfm6m8, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_uHAkCt42, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_rDS9Bo1F, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_ikZ0xpg0, VOf(Bf2));
    __hv_line_f(&sLine_pHEvOFrb, VOf(Bf6));
    __hv_line_f(&sLine_jJRJyVCy, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_5Nbj91WB, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_oKNxUuc2, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_acctVbjZ, VOf(Bf8));
    __hv_line_f(&sLine_mrQv5wUh, VOf(Bf2));
    __hv_line_f(&sLine_dCVuU4pg, VOf(Bf1));
    __hv_line_f(&sLine_TXuHgU9H, VOf(Bf7));
    __hv_line_f(&sLine_yFI4FULV, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_3CwcCdB3, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_MqlUk40j, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_UQJvqx8y, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_lXcFKYBf, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_G3plSuL4, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_ACQIkKjG, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Cy0tcwIZ, VOf(Bf8));
    __hv_rpole_f(&sRPole_l9iryK7c, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_a4UpEMO1, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_4nSKrMYS, VOf(Bf10));
    __hv_rpole_f(&sRPole_32wHJ1dz, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_VvZYvazG, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_VdJTyCeg, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_ZvRcfCFh, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_v2tA4D1T, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_JlXlUeyD, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_880xZFb2, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_KyJADjIw, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_cootdAQ8, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_EKYTXHPE, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_CTOwbg1i, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_vsAeVip9, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_0HfuxyrF, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_HL7hjG99, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_xGIFBky0, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_WUbZ1xYw, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_gzEULu5U, VIf(Bf3));
    __hv_varwrite_f(&sVarf_0x4lrt8Z, VIf(Bf11));
    __hv_line_f(&sLine_FbWgKnbR, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_Raj7ZeNN, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_CQ6gJjcR, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_Fkpb8h1q, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_zNyL3kzj, VOf(Bf10));
    __hv_rpole_f(&sRPole_0tTcezA5, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Zv5ujA3e, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_6GZ4ThXZ, VOf(Bf5));
    __hv_rpole_f(&sRPole_oyWeuS7P, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_LRN8UJjL, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_oNWYSEWR, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Rbda3ll1, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_6qaoWCeX, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_kPC0lO9A, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_2eYOOOD5, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_B4zEHYRA, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_0J1SEk3q, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_I6w7OXmC, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_SbSna2LP, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_Wfj17syK, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_dWYOeE6x, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_SSMA6h4A, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_zj4qC4ub, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_RXxH6vd1, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_mskV5GBr, VIf(Bf0));
    __hv_varwrite_f(&sVarf_NekcUCOR, VIf(Bf8));
    __hv_line_f(&sLine_Hxyd87Bh, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_Lh6tQE6Z, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_XDF2IpD5, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_AgamUPlM, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_z0VlazzF, VOf(Bf5));
    __hv_rpole_f(&sRPole_XfnWXOb9, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_GLNZcCTg, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_30yIHaW8, VOf(Bf6));
    __hv_rpole_f(&sRPole_Yvox35W4, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_jAkFHcxf, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_A4MscM5E, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_X8B2vEvx, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_8g6uI2dG, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_kv7MimPw, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_u5Sal4vQ, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_weiJAgS1, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_bIeUymo5, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_UN65DTka, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_9u4ry4Xv, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_ddighjGB, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_ENtJTifd, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_4LzA5ZiX, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_XA0p8U5G, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_I85rRx8m, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_dYXTzyMc, VIf(Bf4));
    __hv_varwrite_f(&sVarf_8xrWvZyF, VIf(Bf10));
    __hv_varwrite_f(&sVarf_fldbemG9, VIf(Bf2));
    __hv_varwrite_f(&sVarf_C4eAI0b3, VIf(Bf9));
    __hv_varwrite_f(&sVarf_6U4LRD4I, VIf(Bf11));
    __hv_varread_f(&sVarf_0x4lrt8Z, VOf(Bf11));
    __hv_varread_f(&sVarf_NekcUCOR, VOf(Bf9));
    __hv_varread_f(&sVarf_8xrWvZyF, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_fldbemG9, VOf(Bf2));
    __hv_varread_f(&sVarf_C4eAI0b3, VOf(Bf11));
    __hv_varread_f(&sVarf_6U4LRD4I, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
